# Change Log
==========

0.3.7 (07.05.2021)
------------------
- First Relase: stable version
- A new feature added: `markdown_name=False` - when `True`, display only a string with a file `file_name` inside `![SegmentLocal](file_name.file_format)` string. You can paste this string into markdown in for example: **Jupyter Notebook**. When executed, it will display the picture inside markown's cell.